## How to use the ARIclicker? 

**explanation:** 
"ARIclicker" is "Auto Random Interval clicker".

 This is a very good autoclicker, easy to use and intelligent.


### **First of all** 

You need to install **ARIclicker**: Open `cmd` and type `pip install ARIclicker`

### Function:

**syntax:**

clicker:
`
ARIclicker.autoclick("start_pause_key","end_key","min_interval(sec)","max_interval(sec)","button")
`

presser:
`
ARIclicker.autopress("start_pause_key","end_key","pressed_button")
`

example 1:
<pre>
	import ARIclicker 
	ARIclicker.autoclick("a","b","0.1","1","left")
	
</pre>

**explanation:** If you press the "a" key, clicking will start. When you press the "a" key again, clicking will pause. When you press the "b" key, the program will exit. The range of click intervals is between 0.1 and 1 second, and the left mouse button is the key clicked.

example 2:
<pre>
	import ARIclicker
	ARIclicker.autopress("a","b","c")
</pre>

**explanation:** If you press the "a" key,pressing will start.When you press the "a" key again, pressing will pause.When you press the "b" key, the program will exit.The 'c' key represents the key that will be pressed.


 ### **have fun~**










